[![Build Status](https://travis-ci.org/christianbrodbeck/Eelbrain.svg?branch=master)](https://travis-ci.org/christianbrodbeck/Eelbrain) 
[![Appveyor Status](https://ci.appveyor.com/api/projects/status/5rwhgtsfku953f12/branch/master?svg=true)](https://ci.appveyor.com/project/christianbrodbeck/eelbrain/branch/master)
[![Documentation Status](https://readthedocs.org/projects/eelbrain/badge/?version=latest)](http://eelbrain.readthedocs.io/en/r-0.24/?badge=r-0.24) 
[![DOI](https://zenodo.org/badge/3651023.svg)](https://zenodo.org/badge/latestdoi/3651023)


# Eelbrain

The documentation is located at: http://eelbrain.readthedocs.io
